""" CISCO_EMBEDDED_EVENT_MGR_MIB 

The MIB module to describe and store events generated
by the Cisco Embedded Event Manager.  

The Cisco Embedded Event Manager detects hardware and software 
faults, and other events (such as OIRs) for the system.
It also enables users to configure fault recovery services
for system wide components.  The Embedded Event Manager also 
provides process reliability statistics.

The Embedded Event Manager is a policy driven process through 
which faults in the system are reported through a defined API.
The Embedded Event Manager policy engine receives notifications
when faults and other events occur.  Embedded Event Manager 
policies implement recovery based on the current state of the 
system and the actions specified in the policy for a given 
event.  Recovery actions are triggered when the policy is 
run.  Developers write and customize Embedded Event Manager 
policies to handle faults and events.

"""


import re
import collections

from enum import Enum

from ydk.types import Empty, YList, YLeafList, DELETE, Decimal64, FixedBitsDict

from ydk.errors import YPYError, YPYModelError



class NotifysourceEnum(Enum):
    """
    NotifysourceEnum

    The notification source of the history entry.

    server \- Notification was sent by the Embedded Event 

             Manager server.

    policy \- Notification was sent from within an Embedded 

             Event Manager policy.

    .. data:: server = 1

    .. data:: policy = 2

    """

    server = 1

    policy = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xe._meta import _CISCO_EMBEDDED_EVENT_MGR_MIB as meta
        return meta._meta_table['NotifysourceEnum']



class CiscoEmbeddedEventMgrMib(object):
    """
    
    
    .. attribute:: ceemeventmaptable
    
    	A table containing information about ceemEventIndex value mapping.  Each conceptual row specifies a  unique mapping between a ceemEventIndex value, and a  Embedded Event Manager event type.  Rows are added  dynamically as the Embedded Event Manager server learns of new event types.  This occurs when Embedded Event  Manager Event Detectors register with the Embedded  Event Manager server
    	**type**\:   :py:class:`Ceemeventmaptable <ydk.models.cisco_ios_xe.CISCO_EMBEDDED_EVENT_MGR_MIB.CiscoEmbeddedEventMgrMib.Ceemeventmaptable>`
    
    .. attribute:: ceemhistory
    
    	
    	**type**\:   :py:class:`Ceemhistory <ydk.models.cisco_ios_xe.CISCO_EMBEDDED_EVENT_MGR_MIB.CiscoEmbeddedEventMgrMib.Ceemhistory>`
    
    .. attribute:: ceemhistoryeventtable
    
    	A table of Embedded Event Manager events generated by this router.  Conceptual row entries are dynamically added into  this table when Embedded Event Manager events occur.  Entries are stored in FIFO order.  When the maximum number  of entries has been reached in the table, the oldest entry  in the table is removed immediately.    When a table is reduced to a smaller size N, the oldest entries are immediately removed from the table leaving  a maximum of N entries
    	**type**\:   :py:class:`Ceemhistoryeventtable <ydk.models.cisco_ios_xe.CISCO_EMBEDDED_EVENT_MGR_MIB.CiscoEmbeddedEventMgrMib.Ceemhistoryeventtable>`
    
    .. attribute:: ceemregisteredpolicytable
    
    	A table of Embedded Event Manager policies registered on a system. The number of entries depends on the configuration of the system.  The  maximum number is implementation dependent
    	**type**\:   :py:class:`Ceemregisteredpolicytable <ydk.models.cisco_ios_xe.CISCO_EMBEDDED_EVENT_MGR_MIB.CiscoEmbeddedEventMgrMib.Ceemregisteredpolicytable>`
    
    

    """

    _prefix = 'CISCO-EMBEDDED-EVENT-MGR-MIB'
    _revision = '2006-11-07'

    def __init__(self):
        self.ceemeventmaptable = CiscoEmbeddedEventMgrMib.Ceemeventmaptable()
        self.ceemeventmaptable.parent = self
        self.ceemhistory = CiscoEmbeddedEventMgrMib.Ceemhistory()
        self.ceemhistory.parent = self
        self.ceemhistoryeventtable = CiscoEmbeddedEventMgrMib.Ceemhistoryeventtable()
        self.ceemhistoryeventtable.parent = self
        self.ceemregisteredpolicytable = CiscoEmbeddedEventMgrMib.Ceemregisteredpolicytable()
        self.ceemregisteredpolicytable.parent = self


    class Ceemhistory(object):
        """
        
        
        .. attribute:: ceemhistorylastevententry
        
        	Index of last entry created in ceemHistoryEventTable
        	**type**\:  int
        
        	**range:** 1..4294967295
        
        .. attribute:: ceemhistorymaxevententries
        
        	The maximum number of entries that can be held in ceemHistoryEventTable
        	**type**\:  int
        
        	**range:** 0..50
        
        

        """

        _prefix = 'CISCO-EMBEDDED-EVENT-MGR-MIB'
        _revision = '2006-11-07'

        def __init__(self):
            self.parent = None
            self.ceemhistorylastevententry = None
            self.ceemhistorymaxevententries = None

        @property
        def _common_path(self):

            return '/CISCO-EMBEDDED-EVENT-MGR-MIB:CISCO-EMBEDDED-EVENT-MGR-MIB/CISCO-EMBEDDED-EVENT-MGR-MIB:ceemHistory'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if self.ceemhistorylastevententry is not None:
                return True

            if self.ceemhistorymaxevententries is not None:
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xe._meta import _CISCO_EMBEDDED_EVENT_MGR_MIB as meta
            return meta._meta_table['CiscoEmbeddedEventMgrMib.Ceemhistory']['meta_info']


    class Ceemeventmaptable(object):
        """
        A table containing information about ceemEventIndex
        value mapping.  Each conceptual row specifies a 
        unique mapping between a ceemEventIndex value, and a 
        Embedded Event Manager event type.  Rows are added 
        dynamically as the Embedded Event Manager server learns
        of new event types.  This occurs when Embedded Event 
        Manager Event Detectors register with the Embedded 
        Event Manager server.
        
        .. attribute:: ceemeventmapentry
        
        	A mapping between an event type and an event description
        	**type**\: list of    :py:class:`Ceemeventmapentry <ydk.models.cisco_ios_xe.CISCO_EMBEDDED_EVENT_MGR_MIB.CiscoEmbeddedEventMgrMib.Ceemeventmaptable.Ceemeventmapentry>`
        
        

        """

        _prefix = 'CISCO-EMBEDDED-EVENT-MGR-MIB'
        _revision = '2006-11-07'

        def __init__(self):
            self.parent = None
            self.ceemeventmapentry = YList()
            self.ceemeventmapentry.parent = self
            self.ceemeventmapentry.name = 'ceemeventmapentry'


        class Ceemeventmapentry(object):
            """
            A mapping between an event type and an event description.
            
            .. attribute:: ceemeventindex  <key>
            
            	This object uniquely identifies an event.  Events are not persisted across reloads
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemeventdescrtext
            
            	This object specifies a human\-readable message describing information about the  Embedded Event Manager event
            	**type**\:  str
            
            .. attribute:: ceemeventname
            
            	The name of the Embedded Event Manager event
            	**type**\:  str
            
            	**length:** 1..128
            
            

            """

            _prefix = 'CISCO-EMBEDDED-EVENT-MGR-MIB'
            _revision = '2006-11-07'

            def __init__(self):
                self.parent = None
                self.ceemeventindex = None
                self.ceemeventdescrtext = None
                self.ceemeventname = None

            @property
            def _common_path(self):
                if self.ceemeventindex is None:
                    raise YPYModelError('Key property ceemeventindex is None')

                return '/CISCO-EMBEDDED-EVENT-MGR-MIB:CISCO-EMBEDDED-EVENT-MGR-MIB/CISCO-EMBEDDED-EVENT-MGR-MIB:ceemEventMapTable/CISCO-EMBEDDED-EVENT-MGR-MIB:ceemEventMapEntry[CISCO-EMBEDDED-EVENT-MGR-MIB:ceemEventIndex = ' + str(self.ceemeventindex) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if self.ceemeventindex is not None:
                    return True

                if self.ceemeventdescrtext is not None:
                    return True

                if self.ceemeventname is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xe._meta import _CISCO_EMBEDDED_EVENT_MGR_MIB as meta
                return meta._meta_table['CiscoEmbeddedEventMgrMib.Ceemeventmaptable.Ceemeventmapentry']['meta_info']

        @property
        def _common_path(self):

            return '/CISCO-EMBEDDED-EVENT-MGR-MIB:CISCO-EMBEDDED-EVENT-MGR-MIB/CISCO-EMBEDDED-EVENT-MGR-MIB:ceemEventMapTable'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if self.ceemeventmapentry is not None:
                for child_ref in self.ceemeventmapentry:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xe._meta import _CISCO_EMBEDDED_EVENT_MGR_MIB as meta
            return meta._meta_table['CiscoEmbeddedEventMgrMib.Ceemeventmaptable']['meta_info']


    class Ceemhistoryeventtable(object):
        """
        A table of Embedded Event Manager events generated by this
        router.  Conceptual row entries are dynamically added into 
        this table when Embedded Event Manager events occur.
        
        Entries are stored in FIFO order.  When the maximum number 
        of entries has been reached in the table, the oldest entry 
        in the table is removed immediately.  
        
        When a table is reduced to a smaller size N, the oldest
        entries are immediately removed from the table leaving 
        a maximum of N entries.
        
        .. attribute:: ceemhistoryevententry
        
        	Information about an Embedded Event Manager event which has been generated by this router.  It provides up to four event types to support complex event specifications that are triggered when multiple events are published within a certain period of time
        	**type**\: list of    :py:class:`Ceemhistoryevententry <ydk.models.cisco_ios_xe.CISCO_EMBEDDED_EVENT_MGR_MIB.CiscoEmbeddedEventMgrMib.Ceemhistoryeventtable.Ceemhistoryevententry>`
        
        

        """

        _prefix = 'CISCO-EMBEDDED-EVENT-MGR-MIB'
        _revision = '2006-11-07'

        def __init__(self):
            self.parent = None
            self.ceemhistoryevententry = YList()
            self.ceemhistoryevententry.parent = self
            self.ceemhistoryevententry.name = 'ceemhistoryevententry'


        class Ceemhistoryevententry(object):
            """
            Information about an Embedded Event Manager event which has
            been generated by this router.  It provides up to four event
            types to support complex event specifications that are
            triggered when multiple events are published within a certain
            period of time.
            
            .. attribute:: ceemhistoryeventindex  <key>
            
            	A monotonically increasing non\-zero integer uniquely identifying a generated event.  When it reaches the  maximum value, the agent wraps the value back to 1  and may flush all existing entries in the event table
            	**type**\:  int
            
            	**range:** 1..4294967295
            
            .. attribute:: ceemhistoryeventtype1
            
            	The type of Embedded Event Manager event which was detected. The value corresponds to an entry in the  ceemEventTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemhistoryeventtype2
            
            	The type of Embedded Event Manager event which was detected. The value corresponds to an entry in the  ceemEventTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemhistoryeventtype3
            
            	The type of Embedded Event Manager event which was detected. The value corresponds to an entry in the  ceemEventTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemhistoryeventtype4
            
            	The type of Embedded Event Manager event which was detected. The value corresponds to an entry in the ceemEventTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemhistoryeventtype5
            
            	The type of Embedded Event Manager event which was detected. The value corresponds to an entry in the  ceemEventTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemhistoryeventtype6
            
            	The type of Embedded Event Manager event which was detected. The value corresponds to an entry in the  ceemEventTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemhistoryeventtype7
            
            	The type of Embedded Event Manager event which was detected. The value corresponds to an entry in the  ceemEventTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemhistoryeventtype8
            
            	The type of Embedded Event Manager event which was detected. The value corresponds to an entry in the  ceemEventTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemhistorynotifytype
            
            	The notification type that was sent from the Embedded Event Manager.  The valid values are server or policy
            	**type**\:   :py:class:`NotifysourceEnum <ydk.models.cisco_ios_xe.CISCO_EMBEDDED_EVENT_MGR_MIB.NotifysourceEnum>`
            
            .. attribute:: ceemhistorypolicyexitstatus
            
            	The exit status of the Embedded Event Manager policy execution.  This value corresponds to the Posix process  exit status
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: ceemhistorypolicyintdata1
            
            	Arbitrary integer data that the Embedded Event Manager policy can use. Use of this object is optional. If unused by a policy, this object will not be instantiated for  that policy
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: ceemhistorypolicyintdata2
            
            	Arbitrary integer data that the Embedded Event Manager policy can use. Use of this object is optional. If unused by a policy, this object will not be instantiated for  that policy
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: ceemhistorypolicyname
            
            	The name of the Embedded Event Manager policy that was triggered because of an Embedded Event Manager event. The name must be a valid Embedded Event Manager policy name.  It must be in the form of a valid Posix filename
            	**type**\:  str
            
            	**length:** 0..128
            
            .. attribute:: ceemhistorypolicypath
            
            	The file path on the router where the Embedded Event Manager policy that was triggered is stored.  If the size of the  file path string is larger than 128, the end characters  will be truncated
            	**type**\:  str
            
            	**length:** 0..128
            
            .. attribute:: ceemhistorypolicystrdata
            
            	Arbitrary string data the Embedded Event Manager policy can use.  Use of this object is optional.  If unused by a policy, this object will not be instantiated for  that policy
            	**type**\:  str
            
            	**length:** 0..255
            
            

            """

            _prefix = 'CISCO-EMBEDDED-EVENT-MGR-MIB'
            _revision = '2006-11-07'

            def __init__(self):
                self.parent = None
                self.ceemhistoryeventindex = None
                self.ceemhistoryeventtype1 = None
                self.ceemhistoryeventtype2 = None
                self.ceemhistoryeventtype3 = None
                self.ceemhistoryeventtype4 = None
                self.ceemhistoryeventtype5 = None
                self.ceemhistoryeventtype6 = None
                self.ceemhistoryeventtype7 = None
                self.ceemhistoryeventtype8 = None
                self.ceemhistorynotifytype = None
                self.ceemhistorypolicyexitstatus = None
                self.ceemhistorypolicyintdata1 = None
                self.ceemhistorypolicyintdata2 = None
                self.ceemhistorypolicyname = None
                self.ceemhistorypolicypath = None
                self.ceemhistorypolicystrdata = None

            @property
            def _common_path(self):
                if self.ceemhistoryeventindex is None:
                    raise YPYModelError('Key property ceemhistoryeventindex is None')

                return '/CISCO-EMBEDDED-EVENT-MGR-MIB:CISCO-EMBEDDED-EVENT-MGR-MIB/CISCO-EMBEDDED-EVENT-MGR-MIB:ceemHistoryEventTable/CISCO-EMBEDDED-EVENT-MGR-MIB:ceemHistoryEventEntry[CISCO-EMBEDDED-EVENT-MGR-MIB:ceemHistoryEventIndex = ' + str(self.ceemhistoryeventindex) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if self.ceemhistoryeventindex is not None:
                    return True

                if self.ceemhistoryeventtype1 is not None:
                    return True

                if self.ceemhistoryeventtype2 is not None:
                    return True

                if self.ceemhistoryeventtype3 is not None:
                    return True

                if self.ceemhistoryeventtype4 is not None:
                    return True

                if self.ceemhistoryeventtype5 is not None:
                    return True

                if self.ceemhistoryeventtype6 is not None:
                    return True

                if self.ceemhistoryeventtype7 is not None:
                    return True

                if self.ceemhistoryeventtype8 is not None:
                    return True

                if self.ceemhistorynotifytype is not None:
                    return True

                if self.ceemhistorypolicyexitstatus is not None:
                    return True

                if self.ceemhistorypolicyintdata1 is not None:
                    return True

                if self.ceemhistorypolicyintdata2 is not None:
                    return True

                if self.ceemhistorypolicyname is not None:
                    return True

                if self.ceemhistorypolicypath is not None:
                    return True

                if self.ceemhistorypolicystrdata is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xe._meta import _CISCO_EMBEDDED_EVENT_MGR_MIB as meta
                return meta._meta_table['CiscoEmbeddedEventMgrMib.Ceemhistoryeventtable.Ceemhistoryevententry']['meta_info']

        @property
        def _common_path(self):

            return '/CISCO-EMBEDDED-EVENT-MGR-MIB:CISCO-EMBEDDED-EVENT-MGR-MIB/CISCO-EMBEDDED-EVENT-MGR-MIB:ceemHistoryEventTable'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if self.ceemhistoryevententry is not None:
                for child_ref in self.ceemhistoryevententry:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xe._meta import _CISCO_EMBEDDED_EVENT_MGR_MIB as meta
            return meta._meta_table['CiscoEmbeddedEventMgrMib.Ceemhistoryeventtable']['meta_info']


    class Ceemregisteredpolicytable(object):
        """
        A table of Embedded Event Manager policies registered on a system.
        The number of entries depends on the configuration of the system.  The 
        maximum number is implementation dependent.
        
        .. attribute:: ceemregisteredpolicyentry
        
        	An entry in the table of Embedded Event Manager policies that are registered.  It provides up to four event types to support complex  event specifications that are triggered when multiple events are  published within a certain period of time.  A row in this table  cannot be created or deleted by SNMP operations on columns of the  table
        	**type**\: list of    :py:class:`Ceemregisteredpolicyentry <ydk.models.cisco_ios_xe.CISCO_EMBEDDED_EVENT_MGR_MIB.CiscoEmbeddedEventMgrMib.Ceemregisteredpolicytable.Ceemregisteredpolicyentry>`
        
        

        """

        _prefix = 'CISCO-EMBEDDED-EVENT-MGR-MIB'
        _revision = '2006-11-07'

        def __init__(self):
            self.parent = None
            self.ceemregisteredpolicyentry = YList()
            self.ceemregisteredpolicyentry.parent = self
            self.ceemregisteredpolicyentry.name = 'ceemregisteredpolicyentry'


        class Ceemregisteredpolicyentry(object):
            """
            An entry in the table of Embedded Event Manager policies that are
            registered.  It provides up to four event types to support complex 
            event specifications that are triggered when multiple events are 
            published within a certain period of time.  A row in this table 
            cannot be created or deleted by SNMP operations on columns of the 
            table.
            
            .. attribute:: ceemregisteredpolicyindex  <key>
            
            	A monotonically increasing non\-zero integer uniquely identifying a policy registration.  When it reaches the maximum value, the agent wraps the value back to 1 upon  receiving the next policy registration
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemregisteredpolicyenabledtime
            
            	The time the policy was last enabled.  It is stored as a 32\-bit count of seconds since 0000 UTC, 1 January, 1970
            	**type**\:  str
            
            .. attribute:: ceemregisteredpolicyeventtype1
            
            	The type of Embedded Event Manager event which was registered by the policy. The value corresponds to an entry in the ceemEventMapTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemregisteredpolicyeventtype2
            
            	The type of Embedded Event Manager event which was registered by the policy. The value corresponds to an entry in the ceemEventMapTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemregisteredpolicyeventtype3
            
            	The type of Embedded Event Manager event which was registered by the policy. The value corresponds to an entry in the ceemEventMapTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemregisteredpolicyeventtype4
            
            	The type of Embedded Event Manager event which was registered by the policy. The value corresponds to an entry in the ceemEventMapTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemregisteredpolicyeventtype5
            
            	The type of Embedded Event Manager event which was registered by the policy. The value corresponds to an entry in the ceemEventMapTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemregisteredpolicyeventtype6
            
            	The type of Embedded Event Manager event which was registered by the policy. The value corresponds to an entry in the ceemEventMapTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemregisteredpolicyeventtype7
            
            	The type of Embedded Event Manager event which was registered by the policy. The value corresponds to an entry in the ceemEventMapTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemregisteredpolicyeventtype8
            
            	The type of Embedded Event Manager event which was registered by the policy. The value corresponds to an entry in the ceemEventMapTable
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemregisteredpolicyname
            
            	The name of the Embedded Event Manager policy that was registered.  The name must be a valid Embedded Event  Manager policy name. It must be in the form of a valid  Posix filename
            	**type**\:  str
            
            	**length:** 0..128
            
            .. attribute:: ceemregisteredpolicynotifflag
            
            	This flag indicates if an SNMP notification will be sent when policy is triggered
            	**type**\:  bool
            
            .. attribute:: ceemregisteredpolicyregtime
            
            	The time the policy was registered.  It is stored as a 32\-bit count of seconds since 0000 UTC, 1 January, 1970
            	**type**\:  str
            
            .. attribute:: ceemregisteredpolicyruncount
            
            	The number of times the policy has been run
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ceemregisteredpolicyruntime
            
            	The last time the policy was run.  It is stored as a 32\-bit count of seconds since 0000 UTC, 1 January, 1970
            	**type**\:  str
            
            .. attribute:: ceemregisteredpolicystatus
            
            	This status indicates whether the policy is enabled or disabled
            	**type**\:   :py:class:`CeemregisteredpolicystatusEnum <ydk.models.cisco_ios_xe.CISCO_EMBEDDED_EVENT_MGR_MIB.CiscoEmbeddedEventMgrMib.Ceemregisteredpolicytable.Ceemregisteredpolicyentry.CeemregisteredpolicystatusEnum>`
            
            .. attribute:: ceemregisteredpolicytype
            
            	This variable indicates whether this is a user or system policy
            	**type**\:   :py:class:`CeemregisteredpolicytypeEnum <ydk.models.cisco_ios_xe.CISCO_EMBEDDED_EVENT_MGR_MIB.CiscoEmbeddedEventMgrMib.Ceemregisteredpolicytable.Ceemregisteredpolicyentry.CeemregisteredpolicytypeEnum>`
            
            

            """

            _prefix = 'CISCO-EMBEDDED-EVENT-MGR-MIB'
            _revision = '2006-11-07'

            def __init__(self):
                self.parent = None
                self.ceemregisteredpolicyindex = None
                self.ceemregisteredpolicyenabledtime = None
                self.ceemregisteredpolicyeventtype1 = None
                self.ceemregisteredpolicyeventtype2 = None
                self.ceemregisteredpolicyeventtype3 = None
                self.ceemregisteredpolicyeventtype4 = None
                self.ceemregisteredpolicyeventtype5 = None
                self.ceemregisteredpolicyeventtype6 = None
                self.ceemregisteredpolicyeventtype7 = None
                self.ceemregisteredpolicyeventtype8 = None
                self.ceemregisteredpolicyname = None
                self.ceemregisteredpolicynotifflag = None
                self.ceemregisteredpolicyregtime = None
                self.ceemregisteredpolicyruncount = None
                self.ceemregisteredpolicyruntime = None
                self.ceemregisteredpolicystatus = None
                self.ceemregisteredpolicytype = None

            class CeemregisteredpolicystatusEnum(Enum):
                """
                CeemregisteredpolicystatusEnum

                This status indicates whether the policy is enabled or disabled.

                .. data:: enabled = 1

                .. data:: disabled = 2

                """

                enabled = 1

                disabled = 2


                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xe._meta import _CISCO_EMBEDDED_EVENT_MGR_MIB as meta
                    return meta._meta_table['CiscoEmbeddedEventMgrMib.Ceemregisteredpolicytable.Ceemregisteredpolicyentry.CeemregisteredpolicystatusEnum']


            class CeemregisteredpolicytypeEnum(Enum):
                """
                CeemregisteredpolicytypeEnum

                This variable indicates whether this is a user or system policy.

                .. data:: user = 1

                .. data:: system = 2

                """

                user = 1

                system = 2


                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xe._meta import _CISCO_EMBEDDED_EVENT_MGR_MIB as meta
                    return meta._meta_table['CiscoEmbeddedEventMgrMib.Ceemregisteredpolicytable.Ceemregisteredpolicyentry.CeemregisteredpolicytypeEnum']


            @property
            def _common_path(self):
                if self.ceemregisteredpolicyindex is None:
                    raise YPYModelError('Key property ceemregisteredpolicyindex is None')

                return '/CISCO-EMBEDDED-EVENT-MGR-MIB:CISCO-EMBEDDED-EVENT-MGR-MIB/CISCO-EMBEDDED-EVENT-MGR-MIB:ceemRegisteredPolicyTable/CISCO-EMBEDDED-EVENT-MGR-MIB:ceemRegisteredPolicyEntry[CISCO-EMBEDDED-EVENT-MGR-MIB:ceemRegisteredPolicyIndex = ' + str(self.ceemregisteredpolicyindex) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if self.ceemregisteredpolicyindex is not None:
                    return True

                if self.ceemregisteredpolicyenabledtime is not None:
                    return True

                if self.ceemregisteredpolicyeventtype1 is not None:
                    return True

                if self.ceemregisteredpolicyeventtype2 is not None:
                    return True

                if self.ceemregisteredpolicyeventtype3 is not None:
                    return True

                if self.ceemregisteredpolicyeventtype4 is not None:
                    return True

                if self.ceemregisteredpolicyeventtype5 is not None:
                    return True

                if self.ceemregisteredpolicyeventtype6 is not None:
                    return True

                if self.ceemregisteredpolicyeventtype7 is not None:
                    return True

                if self.ceemregisteredpolicyeventtype8 is not None:
                    return True

                if self.ceemregisteredpolicyname is not None:
                    return True

                if self.ceemregisteredpolicynotifflag is not None:
                    return True

                if self.ceemregisteredpolicyregtime is not None:
                    return True

                if self.ceemregisteredpolicyruncount is not None:
                    return True

                if self.ceemregisteredpolicyruntime is not None:
                    return True

                if self.ceemregisteredpolicystatus is not None:
                    return True

                if self.ceemregisteredpolicytype is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xe._meta import _CISCO_EMBEDDED_EVENT_MGR_MIB as meta
                return meta._meta_table['CiscoEmbeddedEventMgrMib.Ceemregisteredpolicytable.Ceemregisteredpolicyentry']['meta_info']

        @property
        def _common_path(self):

            return '/CISCO-EMBEDDED-EVENT-MGR-MIB:CISCO-EMBEDDED-EVENT-MGR-MIB/CISCO-EMBEDDED-EVENT-MGR-MIB:ceemRegisteredPolicyTable'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if self.ceemregisteredpolicyentry is not None:
                for child_ref in self.ceemregisteredpolicyentry:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xe._meta import _CISCO_EMBEDDED_EVENT_MGR_MIB as meta
            return meta._meta_table['CiscoEmbeddedEventMgrMib.Ceemregisteredpolicytable']['meta_info']

    @property
    def _common_path(self):

        return '/CISCO-EMBEDDED-EVENT-MGR-MIB:CISCO-EMBEDDED-EVENT-MGR-MIB'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if self.ceemeventmaptable is not None and self.ceemeventmaptable._has_data():
            return True

        if self.ceemhistory is not None and self.ceemhistory._has_data():
            return True

        if self.ceemhistoryeventtable is not None and self.ceemhistoryeventtable._has_data():
            return True

        if self.ceemregisteredpolicytable is not None and self.ceemregisteredpolicytable._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xe._meta import _CISCO_EMBEDDED_EVENT_MGR_MIB as meta
        return meta._meta_table['CiscoEmbeddedEventMgrMib']['meta_info']


