""" CISCO_SYSLOG_MIB 

The MIB module to describe and store the system
messages generated by the IOS and any other
OS which supports syslogs.

"""


import re
import collections

from enum import Enum

from ydk.types import Empty, YList, YLeafList, DELETE, Decimal64, FixedBitsDict

from ydk.errors import YPYError, YPYModelError



class SyslogseverityEnum(Enum):
    """
    SyslogseverityEnum

    The severity of a syslog message.  The enumeration

    values are equal to the values that syslog uses + 1.

    For example, with syslog, emergency=0.

     'emergency' \: system is unusable

     'alert'     \: action must be taken immediately

     'critical'  \: critical conditions

     'error'     \: error conditions

     'warning'   \: warning conditions

     'notice'    \: normal but significant condition

     'informational'\: informational messages 

     'debug'        \: debug\-level messages.

    .. data:: emergency = 1

    .. data:: alert = 2

    .. data:: critical = 3

    .. data:: error = 4

    .. data:: warning = 5

    .. data:: notice = 6

    .. data:: info = 7

    .. data:: debug = 8

    """

    emergency = 1

    alert = 2

    critical = 3

    error = 4

    warning = 5

    notice = 6

    info = 7

    debug = 8


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xe._meta import _CISCO_SYSLOG_MIB as meta
        return meta._meta_table['SyslogseverityEnum']



class CiscoSyslogMib(object):
    """
    
    
    .. attribute:: clogbasic
    
    	
    	**type**\:   :py:class:`Clogbasic <ydk.models.cisco_ios_xe.CISCO_SYSLOG_MIB.CiscoSyslogMib.Clogbasic>`
    
    .. attribute:: cloghistory
    
    	
    	**type**\:   :py:class:`Cloghistory <ydk.models.cisco_ios_xe.CISCO_SYSLOG_MIB.CiscoSyslogMib.Cloghistory>`
    
    .. attribute:: cloghistorytable
    
    	A table of syslog messages generated by this device. All 'interesting' syslog messages (i.e. severity <= clogMaxSeverity) are entered into this table
    	**type**\:   :py:class:`Cloghistorytable <ydk.models.cisco_ios_xe.CISCO_SYSLOG_MIB.CiscoSyslogMib.Cloghistorytable>`
    
    .. attribute:: clogserver
    
    	
    	**type**\:   :py:class:`Clogserver <ydk.models.cisco_ios_xe.CISCO_SYSLOG_MIB.CiscoSyslogMib.Clogserver>`
    
    .. attribute:: clogserverconfigtable
    
    	This table contains entries that allow application to configure syslog servers for the system.  The maximum number of entries that can be created for this table is limited by the object clogMaxServers
    	**type**\:   :py:class:`Clogserverconfigtable <ydk.models.cisco_ios_xe.CISCO_SYSLOG_MIB.CiscoSyslogMib.Clogserverconfigtable>`
    
    

    """

    _prefix = 'CISCO-SYSLOG-MIB'
    _revision = '2005-12-03'

    def __init__(self):
        self.clogbasic = CiscoSyslogMib.Clogbasic()
        self.clogbasic.parent = self
        self.cloghistory = CiscoSyslogMib.Cloghistory()
        self.cloghistory.parent = self
        self.cloghistorytable = CiscoSyslogMib.Cloghistorytable()
        self.cloghistorytable.parent = self
        self.clogserver = CiscoSyslogMib.Clogserver()
        self.clogserver.parent = self
        self.clogserverconfigtable = CiscoSyslogMib.Clogserverconfigtable()
        self.clogserverconfigtable.parent = self


    class Clogbasic(object):
        """
        
        
        .. attribute:: clogmaxseverity
        
        	Indicates which syslog severity levels will be processed.  Any syslog message with a severity value greater than this value will be ignored by the agent. note\: severity numeric values increase as their severity decreases, e.g. 'error' is more severe than 'debug'
        	**type**\:   :py:class:`SyslogseverityEnum <ydk.models.cisco_ios_xe.CISCO_SYSLOG_MIB.SyslogseverityEnum>`
        
        .. attribute:: clogmsgdrops
        
        	The number of syslog messages which could not be processed due to lack of system resources. Most likely this will occur at the same time that syslog messages are generated to indicate this lack of resources.  Increases in this object's value may serve as an indication that system resource levels should be examined via other mib objects.  A message that is dropped will not appear in the history table and no notification will be sent for this message
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        	**units**\: messages
        
        .. attribute:: clogmsgignores
        
        	The number of syslog messages which were ignored.  A message will be ignored if it has a severity value greater than clogMaxSeverity
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        	**units**\: messages
        
        .. attribute:: clognotificationsenabled
        
        	Indicates whether clogMessageGenerated notifications will or will not be sent when a syslog message is generated by the device.  Disabling notifications does not prevent syslog messages from being added to the clogHistoryTable
        	**type**\:  bool
        
        .. attribute:: clognotificationssent
        
        	The number of clogMessageGenerated notifications that have been sent. This number may include notifications that were prevented from being transmitted due to reasons such as resource limitations and/or non\-connectivity.  If one is receiving notifications, one can periodically poll this object to determine if any notifications were missed.  If so, a poll of the clogHistoryTable might be appropriate
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        	**units**\: notifications
        
        .. attribute:: clogoriginid
        
        	This object is used for configuring the origin identifier for the syslog messages.  The origin identifier is useful for identifying  the source of system logging messages in cases  syslog messages from multiple devices are sent  to a single syslog host. The origin identifier is added to the beginning of all system logging (syslog) messages sent to remote  hosts.  The type of the identifier is specified by clogOriginIDType object.  This object can be written by the SNMP manager only when clogOriginIDType is set to 'userDefined'.  For following value(s) of clogOriginIDType, this object can not be set; the value of this object is derived by the system in these cases\:    'contextName'     'ipv4Address'    'hostName'    'other'         'none'       This object contains the context name of the device, when clogOriginIDType is  set to 'contextName'.  This object contains IPv4 address (in dotted decimal notation) of the sending  interface when clogOriginIDType is set to 'ipv4Address'.  This object contains hostname of the system when clogOriginIDType is set to 'hostName'.  This object will contain zero length octet string when clogOriginIDType is either 'none' or 'other'
        	**type**\:  str
        
        .. attribute:: clogoriginidtype
        
        	This object identifies the type of value that will be contained in clogOriginID object.  The possible value(s) are\:    'none'       \: do not send origin identifier in                    syslog messages.    'other'      \: type that is not identified by other                    values specified in this object.    'hostName'   \: Send hostname of the system in syslog                   messages.    'ipv4Address'\: Send IP address of the sending interface.    'contextName'\: Send context name of the security device.    'userDefined'\: Send user configured string in                   syslog message.     The value 'other' and 'none' can not be set but    can only be read
        	**type**\:   :py:class:`ClogoriginidtypeEnum <ydk.models.cisco_ios_xe.CISCO_SYSLOG_MIB.CiscoSyslogMib.Clogbasic.ClogoriginidtypeEnum>`
        
        

        """

        _prefix = 'CISCO-SYSLOG-MIB'
        _revision = '2005-12-03'

        def __init__(self):
            self.parent = None
            self.clogmaxseverity = None
            self.clogmsgdrops = None
            self.clogmsgignores = None
            self.clognotificationsenabled = None
            self.clognotificationssent = None
            self.clogoriginid = None
            self.clogoriginidtype = None

        class ClogoriginidtypeEnum(Enum):
            """
            ClogoriginidtypeEnum

            This object identifies the type of value that

            will be contained in clogOriginID object.

            The possible value(s) are\:

               'none'       \: do not send origin identifier in 

                              syslog messages.

               'other'      \: type that is not identified by other 

                              values specified in this object.

               'hostName'   \: Send hostname of the system in syslog

                              messages.

               'ipv4Address'\: Send IP address of the sending interface.

               'contextName'\: Send context name of the security device.

               'userDefined'\: Send user configured string in

                              syslog message.

               The value 'other' and 'none' can not be set but

               can only be read.

            .. data:: none = 1

            .. data:: other = 2

            .. data:: hostName = 3

            .. data:: ipv4Address = 4

            .. data:: contextName = 5

            .. data:: userDefined = 6

            """

            none = 1

            other = 2

            hostName = 3

            ipv4Address = 4

            contextName = 5

            userDefined = 6


            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xe._meta import _CISCO_SYSLOG_MIB as meta
                return meta._meta_table['CiscoSyslogMib.Clogbasic.ClogoriginidtypeEnum']


        @property
        def _common_path(self):

            return '/CISCO-SYSLOG-MIB:CISCO-SYSLOG-MIB/CISCO-SYSLOG-MIB:clogBasic'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if self.clogmaxseverity is not None:
                return True

            if self.clogmsgdrops is not None:
                return True

            if self.clogmsgignores is not None:
                return True

            if self.clognotificationsenabled is not None:
                return True

            if self.clognotificationssent is not None:
                return True

            if self.clogoriginid is not None:
                return True

            if self.clogoriginidtype is not None:
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xe._meta import _CISCO_SYSLOG_MIB as meta
            return meta._meta_table['CiscoSyslogMib.Clogbasic']['meta_info']


    class Cloghistory(object):
        """
        
        
        .. attribute:: cloghistmsgsflushed
        
        	The number of entries that have been removed from the clogHistoryTable in order to make room for new entries. This object can be utilized to determine whether your polling frequency on the history table is fast enough and/or the size of your history table is large enough such that you are not missing messages
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        	**units**\: messages
        
        .. attribute:: cloghisttablemaxlength
        
        	The upper limit on the number of entries that the clogHistoryTable may contain.  A value of 0 will prevent any history from being retained. When this table is full, the oldest entry will be deleted and a new one will be created
        	**type**\:  int
        
        	**range:** 0..500
        
        	**units**\: entries
        
        

        """

        _prefix = 'CISCO-SYSLOG-MIB'
        _revision = '2005-12-03'

        def __init__(self):
            self.parent = None
            self.cloghistmsgsflushed = None
            self.cloghisttablemaxlength = None

        @property
        def _common_path(self):

            return '/CISCO-SYSLOG-MIB:CISCO-SYSLOG-MIB/CISCO-SYSLOG-MIB:clogHistory'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if self.cloghistmsgsflushed is not None:
                return True

            if self.cloghisttablemaxlength is not None:
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xe._meta import _CISCO_SYSLOG_MIB as meta
            return meta._meta_table['CiscoSyslogMib.Cloghistory']['meta_info']


    class Clogserver(object):
        """
        
        
        .. attribute:: clogmaxservers
        
        	The maximum number of syslog servers that can be configured for the system in clogServerConfigTable.  A value of zero for this object indicates there is no specified limit for the system and is only dictated by system resources
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        

        """

        _prefix = 'CISCO-SYSLOG-MIB'
        _revision = '2005-12-03'

        def __init__(self):
            self.parent = None
            self.clogmaxservers = None

        @property
        def _common_path(self):

            return '/CISCO-SYSLOG-MIB:CISCO-SYSLOG-MIB/CISCO-SYSLOG-MIB:clogServer'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if self.clogmaxservers is not None:
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xe._meta import _CISCO_SYSLOG_MIB as meta
            return meta._meta_table['CiscoSyslogMib.Clogserver']['meta_info']


    class Cloghistorytable(object):
        """
        A table of syslog messages generated by this device.
        All 'interesting' syslog messages (i.e. severity <=
        clogMaxSeverity) are entered into this table.
        
        .. attribute:: cloghistoryentry
        
        	A syslog message that was previously generated by this device. Each entry is indexed by a message index
        	**type**\: list of    :py:class:`Cloghistoryentry <ydk.models.cisco_ios_xe.CISCO_SYSLOG_MIB.CiscoSyslogMib.Cloghistorytable.Cloghistoryentry>`
        
        

        """

        _prefix = 'CISCO-SYSLOG-MIB'
        _revision = '2005-12-03'

        def __init__(self):
            self.parent = None
            self.cloghistoryentry = YList()
            self.cloghistoryentry.parent = self
            self.cloghistoryentry.name = 'cloghistoryentry'


        class Cloghistoryentry(object):
            """
            A syslog message that was previously generated by this
            device. Each entry is indexed by a message index.
            
            .. attribute:: cloghistindex  <key>
            
            	A monotonically increasing integer for the sole purpose of indexing messages.  When it reaches the maximum value the agent flushes the table and wraps the value back to 1
            	**type**\:  int
            
            	**range:** 1..2147483647
            
            .. attribute:: cloghistfacility
            
            	Name of the facility that generated this message. For example\: 'SYS'
            	**type**\:  str
            
            	**length:** 1..20
            
            .. attribute:: cloghistmsgname
            
            	A textual identification for the message type. A facility name in conjunction with a message name uniquely identifies a message type
            	**type**\:  str
            
            	**length:** 1..30
            
            .. attribute:: cloghistmsgtext
            
            	The text of the message.  If the text of the message exceeds 255 bytes, the message will be truncated to 254 bytes and a '\*' character will be appended \- indicating that the message has been truncated
            	**type**\:  str
            
            	**length:** 1..255
            
            .. attribute:: cloghistseverity
            
            	The severity of the message
            	**type**\:   :py:class:`SyslogseverityEnum <ydk.models.cisco_ios_xe.CISCO_SYSLOG_MIB.SyslogseverityEnum>`
            
            .. attribute:: cloghisttimestamp
            
            	The value of sysUpTime when this message was generated
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'CISCO-SYSLOG-MIB'
            _revision = '2005-12-03'

            def __init__(self):
                self.parent = None
                self.cloghistindex = None
                self.cloghistfacility = None
                self.cloghistmsgname = None
                self.cloghistmsgtext = None
                self.cloghistseverity = None
                self.cloghisttimestamp = None

            @property
            def _common_path(self):
                if self.cloghistindex is None:
                    raise YPYModelError('Key property cloghistindex is None')

                return '/CISCO-SYSLOG-MIB:CISCO-SYSLOG-MIB/CISCO-SYSLOG-MIB:clogHistoryTable/CISCO-SYSLOG-MIB:clogHistoryEntry[CISCO-SYSLOG-MIB:clogHistIndex = ' + str(self.cloghistindex) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if self.cloghistindex is not None:
                    return True

                if self.cloghistfacility is not None:
                    return True

                if self.cloghistmsgname is not None:
                    return True

                if self.cloghistmsgtext is not None:
                    return True

                if self.cloghistseverity is not None:
                    return True

                if self.cloghisttimestamp is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xe._meta import _CISCO_SYSLOG_MIB as meta
                return meta._meta_table['CiscoSyslogMib.Cloghistorytable.Cloghistoryentry']['meta_info']

        @property
        def _common_path(self):

            return '/CISCO-SYSLOG-MIB:CISCO-SYSLOG-MIB/CISCO-SYSLOG-MIB:clogHistoryTable'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if self.cloghistoryentry is not None:
                for child_ref in self.cloghistoryentry:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xe._meta import _CISCO_SYSLOG_MIB as meta
            return meta._meta_table['CiscoSyslogMib.Cloghistorytable']['meta_info']


    class Clogserverconfigtable(object):
        """
        This table contains entries that allow application
        to configure syslog servers for the system.
        
        The maximum number of entries that can be created
        for this table is limited by the object
        clogMaxServers.
        
        .. attribute:: clogserverconfigentry
        
        	An entry containing information about syslog servers configured for the system
        	**type**\: list of    :py:class:`Clogserverconfigentry <ydk.models.cisco_ios_xe.CISCO_SYSLOG_MIB.CiscoSyslogMib.Clogserverconfigtable.Clogserverconfigentry>`
        
        

        """

        _prefix = 'CISCO-SYSLOG-MIB'
        _revision = '2005-12-03'

        def __init__(self):
            self.parent = None
            self.clogserverconfigentry = YList()
            self.clogserverconfigentry.parent = self
            self.clogserverconfigentry.name = 'clogserverconfigentry'


        class Clogserverconfigentry(object):
            """
            An entry containing information about syslog servers
            configured for the system.
            
            .. attribute:: clogserveraddrtype  <key>
            
            	The type of Internet address of this syslog server
            	**type**\:   :py:class:`InetaddresstypeEnum <ydk.models.cisco_ios_xe.INET_ADDRESS_MIB.InetaddresstypeEnum>`
            
            .. attribute:: clogserveraddr  <key>
            
            	The Internet address of this syslog server. The type of this address is determined by the value of the clogServerAddrType object
            	**type**\:  str
            
            	**length:** 0..64
            
            .. attribute:: clogserverstatus
            
            	The status object used to manage rows in this table.  A row may only be created by setting this object to 'createAndGo'.  A row may only be deleted by setting this object to 'destroy'
            	**type**\:   :py:class:`RowstatusEnum <ydk.models.cisco_ios_xe.SNMPv2_TC.RowstatusEnum>`
            
            

            """

            _prefix = 'CISCO-SYSLOG-MIB'
            _revision = '2005-12-03'

            def __init__(self):
                self.parent = None
                self.clogserveraddrtype = None
                self.clogserveraddr = None
                self.clogserverstatus = None

            @property
            def _common_path(self):
                if self.clogserveraddrtype is None:
                    raise YPYModelError('Key property clogserveraddrtype is None')
                if self.clogserveraddr is None:
                    raise YPYModelError('Key property clogserveraddr is None')

                return '/CISCO-SYSLOG-MIB:CISCO-SYSLOG-MIB/CISCO-SYSLOG-MIB:clogServerConfigTable/CISCO-SYSLOG-MIB:clogServerConfigEntry[CISCO-SYSLOG-MIB:clogServerAddrType = ' + str(self.clogserveraddrtype) + '][CISCO-SYSLOG-MIB:clogServerAddr = ' + str(self.clogserveraddr) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if self.clogserveraddrtype is not None:
                    return True

                if self.clogserveraddr is not None:
                    return True

                if self.clogserverstatus is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xe._meta import _CISCO_SYSLOG_MIB as meta
                return meta._meta_table['CiscoSyslogMib.Clogserverconfigtable.Clogserverconfigentry']['meta_info']

        @property
        def _common_path(self):

            return '/CISCO-SYSLOG-MIB:CISCO-SYSLOG-MIB/CISCO-SYSLOG-MIB:clogServerConfigTable'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if self.clogserverconfigentry is not None:
                for child_ref in self.clogserverconfigentry:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xe._meta import _CISCO_SYSLOG_MIB as meta
            return meta._meta_table['CiscoSyslogMib.Clogserverconfigtable']['meta_info']

    @property
    def _common_path(self):

        return '/CISCO-SYSLOG-MIB:CISCO-SYSLOG-MIB'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if self.clogbasic is not None and self.clogbasic._has_data():
            return True

        if self.cloghistory is not None and self.cloghistory._has_data():
            return True

        if self.cloghistorytable is not None and self.cloghistorytable._has_data():
            return True

        if self.clogserver is not None and self.clogserver._has_data():
            return True

        if self.clogserverconfigtable is not None and self.clogserverconfigtable._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xe._meta import _CISCO_SYSLOG_MIB as meta
        return meta._meta_table['CiscoSyslogMib']['meta_info']


